API Reference
=============

.. automodule:: chalc


   .. rubric:: Modules

   .. autosummary::
      :toctree: _autosummary
      :recursive:
      :nosignatures:

      chromatic
      filtration
      sixpack
      plotting